==> robinhood_kafka_python-1.3.7-py2.py3-none-any.whl: rhkafka/__init__.py <==
from __future__ import absolute_import

__title__ = 'rhkafka'
from .version import __version__
__author__ = 'Dana Powers'
__license__ = 'Apache License 2.0'
__copyright__ = 'Copyright 2016 Dana Powers, David Arthur, and Contributors'

__robinhood__ = True

# Set default logging handler to avoid "No handler found" warnings.
import logging
try:  # Python 2.7+
    from logging import NullHandler
except ImportError:
    class NullHandler(logging.Handler):
        def emit(self, record):
            pass

logging.getLogger(__name__).addHandler(NullHandler())


from rhkafka.consumer import KafkaConsumer
from rhkafka.consumer.subscription_state import ConsumerRebalanceListener
from rhkafka.producer import KafkaProducer
from rhkafka.conn import BrokerConnection
from rhkafka.protocol import (
    create_message, create_gzip_message, create_snappy_message)
from rhkafka.partitioner import RoundRobinPartitioner, HashedPartitioner, Murmur2Partitioner
from rhkafka.structs import TopicPartition, OffsetAndMetadata
from rhkafka.serializer import Serializer, Deserializer

# To be deprecated when KafkaProducer interface is released
from rhkafka.client import SimpleClient
from rhkafka.producer import SimpleProducer, KeyedProducer

# deprecated in favor of KafkaConsumer
from rhkafka.consumer import SimpleConsumer, MultiProcessConsumer


import warnings
class KafkaClient(SimpleClient):
    def __init__(self, *args, **kwargs):
        warnings.warn('The legacy KafkaClient interface has been moved to'
                      ' rhkafka.SimpleClient - this import will break in a'
                      ' future release', DeprecationWarning)
        super(KafkaClient, self).__init__(*args, **kwargs)


__all__ = [
    'KafkaConsumer', 'KafkaProducer', 'KafkaClient', 'BrokerConnection',
    'SimpleClient', 'SimpleProducer', 'KeyedProducer',
    'RoundRobinPartitioner', 'HashedPartitioner',
    'create_message', 'create_gzip_message', 'create_snappy_message',
    'SimpleConsumer', 'MultiProcessConsumer',
]

==> robinhood_kafka_python-1.4.3-py2.py3-none-any.whl: rhkafka/__init__.py <==
from __future__ import absolute_import

__title__ = 'kafka'
from rhkafka.version import __version__
__author__ = 'Dana Powers'
__license__ = 'Apache License 2.0'
__copyright__ = 'Copyright 2016 Dana Powers, David Arthur, and Contributors'

__robinhood__ = True

# Set default logging handler to avoid "No handler found" warnings.
import logging
try:  # Python 2.7+
    from logging import NullHandler
except ImportError:
    class NullHandler(logging.Handler):
        def emit(self, record):
            pass

logging.getLogger(__name__).addHandler(NullHandler())


from rhkafka.consumer import KafkaConsumer
from rhkafka.consumer.subscription_state import ConsumerRebalanceListener
from rhkafka.producer import KafkaProducer
from rhkafka.conn import BrokerConnection
from rhkafka.protocol import (
    create_message, create_gzip_message, create_snappy_message)
from rhkafka.partitioner import RoundRobinPartitioner, HashedPartitioner, Murmur2Partitioner
from rhkafka.structs import TopicPartition, OffsetAndMetadata
from rhkafka.serializer import Serializer, Deserializer

# To be deprecated when KafkaProducer interface is released
from rhkafka.client import SimpleClient
from rhkafka.producer import SimpleProducer, KeyedProducer

# deprecated in favor of KafkaConsumer
from rhkafka.consumer import SimpleConsumer, MultiProcessConsumer


import warnings
class KafkaClient(SimpleClient):
    def __init__(self, *args, **kwargs):
        warnings.warn('The legacy KafkaClient interface has been moved to'
                      ' kafka.SimpleClient - this import will break in a'
                      ' future release', DeprecationWarning)
        super(KafkaClient, self).__init__(*args, **kwargs)


__all__ = [
    'KafkaConsumer', 'KafkaProducer', 'KafkaClient', 'BrokerConnection',
    'SimpleClient', 'SimpleProducer', 'KeyedProducer',
    'RoundRobinPartitioner', 'HashedPartitioner',
    'create_message', 'create_gzip_message', 'create_snappy_message',
    'SimpleConsumer', 'MultiProcessConsumer',
]
